/* 
 * Motif Tools Library, Version 3.1
 * $Id: InputField.h,v 1.2 2001/04/15 15:29:36 grmcdorman Exp $
 * 
 * Written by David Flanagan.
 * Copyright (c) 1992-2001 by David Flanagan.
 * All Rights Reserved.  See the file COPYRIGHT for details.
 * This is open source software.  See the file LICENSE for details.
 * There is no warranty for this software.  See NO_WARRANTY for details.
 *
 * $Log: InputField.h,v $
 * Revision 1.2  2001/04/15 15:29:36  grmcdorman
 *   * XmtCallCallback has two new arguments types: XmtRCallbackUserData, which
 *     is the XmNuserData value, and XmtRCallbackImmediate, which is a value
 *     embedded in the list.
 *
 *   * Two new functions, XmtCreateQueryListChildren and XmtCreateQueryListChild,
 *     are provided. They are like the XmtCreate* functions except that they
 *     return a list of the widgets created (quark and pointer to the widget).
 *
 *   * Major enhancements to XmtInputField:
 *     - The input field now has a cancel() action. This reverts the field's
 *       value to that prior to the start of editing (i.e. the last commit).
 *       No default translation is bound to this action, however.
 *     - There is a callback for the cancel action (XmtNcancelCallback).
 *     - The input field can be set to cancel, commit, or do nothing on focus
 *       out. (Previously, it always did a commit). The default is commit.
 *       (XmtNfocusOutAction)
 *
 *   * XmtLayout:
 *     - It now has a losingFocusCallback (XmNloosingFocusCallback).
 *     - It, and the layout widgets (XmtLayoutBox/XmtLayoutString), now
 *       support background pixmaps.
 *     - It now supports XmNresizePolicy.
 *     - Strings in the layout parser are converted to XmStrings by
 *       XtConvertAndStore, so any custom XmString conversion is used
 *       (as, for example, the Xmt convert, which supports the @[]
 *       embedded items)
 *
 *   * Other:
 *     - Pixmaps are convered using XtConvertAndStore, again to allow
 *       custom converters.
 *
 * Bug Fixes: (for Solaris 2.5.1/Motif 1.2/Sparc system)
 *   * XmtInputField did not work properly if the widget had traversalOn
 *     false.
 *   * XmtLayout's child geometry manager was called by Xt when
 *     a shell child was added to the layout; it did not handle
 *     this case.
 *   * XmtLayout had an XmtWarningMsg call with a missing argument (line 2029).
 *   * Widgets automatically created by XmtLayout parsing have been given
 *     non-blank names. [You may wish to tweak this by adding, for example,
 *     a leading underscore.]
 *   * Under some circumstances, XmtNameToWidget could be called during
 *     widget creation, with 'w->core.num_popups' uninitialized. The
 *     workaround applied is to ignore the popup list if the 'num_popups'
 *     value is more than 50 or negative.
 *
 * Revision 1.1.1.1  2001/02/10 13:44:32  motiftools
 * Initial import of Xmt310 to CVS
 *
 *
 */

#ifndef _XmtInputField_h
#define _XmtInputField_h

#include <Xm/Text.h>

typedef enum {
    XmtINPUT_COMMIT,
    XmtINPUT_CANCEL,
    XmtINPUT_NONE
} XmtInputFieldActions;

externalref WidgetClass xmtInputFieldWidgetClass;
typedef struct _XmtInputFieldClassRec *XmtInputFieldWidgetClass;
typedef struct _XmtInputFieldRec *XmtInputFieldWidget;

typedef struct {
    StringConst input;
                   /* this string can be replaced, but not modified or freed */
    Boolean okay;  /* set to False if the string is bad */
                   /* or, set to True to stop error handling */
} XmtInputFieldCallbackStruct;

externalref _Xconst char XmtInputFieldStrings[];
#ifndef XmtNautoDelete
#define XmtNautoDelete ((char*)&XmtInputFieldStrings[0])
#endif
#ifndef XmtNautoInsert
#define XmtNautoInsert ((char*)&XmtInputFieldStrings[11])
#endif
#ifndef XmtNbeepOnError
#define XmtNbeepOnError ((char*)&XmtInputFieldStrings[22])
#endif
#ifndef XmtNbufferSymbolName
#define XmtNbufferSymbolName ((char*)&XmtInputFieldStrings[34])
#endif
#ifndef XmtNcancelCallback
#define XmtNcancelCallback ((char*)&XmtInputFieldStrings[399])
#endif
#ifndef XmtNerrorBackground
#define XmtNerrorBackground ((char*)&XmtInputFieldStrings[51])
#endif
#ifndef XmtNerrorCallback
#define XmtNerrorCallback ((char*)&XmtInputFieldStrings[67])
#endif
#ifndef XmtNerrorForeground
#define XmtNerrorForeground ((char*)&XmtInputFieldStrings[81])
#endif
#ifndef XmtNerrorString
#define XmtNerrorString ((char*)&XmtInputFieldStrings[97])
#endif
#ifndef XmtNfocusOutAction
#define XmtNfocusOutAction ((char*)&XmtInputFieldStrings[414])
#endif
#ifndef XmtNhighlightOnError
#define XmtNhighlightOnError ((char*)&XmtInputFieldStrings[109])
#endif
#ifndef XmtNinput
#define XmtNinput ((char*)&XmtInputFieldStrings[126])
#endif
#ifndef XmtNinputCallback
#define XmtNinputCallback ((char*)&XmtInputFieldStrings[132])
#endif
#ifndef XmtNmatchAll
#define XmtNmatchAll ((char*)&XmtInputFieldStrings[146])
#endif
#ifndef XmtNoverstrike
#define XmtNoverstrike ((char*)&XmtInputFieldStrings[155])
#endif
#ifndef XmtNpattern
#define XmtNpattern ((char*)&XmtInputFieldStrings[166])
#endif
#ifndef XmtNreplaceOnError
#define XmtNreplaceOnError ((char*)&XmtInputFieldStrings[174])
#endif
#ifndef XmtNtargetSymbolName
#define XmtNtargetSymbolName ((char*)&XmtInputFieldStrings[189])
#endif
#ifndef XmtNverifyCallback
#define XmtNverifyCallback ((char*)&XmtInputFieldStrings[206])
#endif
#ifndef XmtCAutoDelete
#define XmtCAutoDelete ((char*)&XmtInputFieldStrings[221])
#endif
#ifndef XmtCAutoInsert
#define XmtCAutoInsert ((char*)&XmtInputFieldStrings[232])
#endif
#ifndef XmtCBeepOnError
#define XmtCBeepOnError ((char*)&XmtInputFieldStrings[243])
#endif
#ifndef XmtCBufferSymbolName
#define XmtCBufferSymbolName ((char*)&XmtInputFieldStrings[255])
#endif
#ifndef XmtCErrorBackground
#define XmtCErrorBackground ((char*)&XmtInputFieldStrings[272])
#endif
#ifndef XmtCErrorForeground
#define XmtCErrorForeground ((char*)&XmtInputFieldStrings[288])
#endif
#ifndef XmtCErrorString
#define XmtCErrorString ((char*)&XmtInputFieldStrings[304])
#endif
#ifndef XmtCFocusOutAction
#define XmtCFocusOutAction ((char*)&XmtInputFieldStrings[429])
#endif
#ifndef XmtCHighlightOnError
#define XmtCHighlightOnError ((char*)&XmtInputFieldStrings[316])
#endif
#ifndef XmtCInput
#define XmtCInput ((char*)&XmtInputFieldStrings[333])
#endif
#ifndef XmtCMatchAll
#define XmtCMatchAll ((char*)&XmtInputFieldStrings[339])
#endif
#ifndef XmtCOverstrike
#define XmtCOverstrike ((char*)&XmtInputFieldStrings[348])
#endif
#ifndef XmtCPattern
#define XmtCPattern ((char*)&XmtInputFieldStrings[359])
#endif
#ifndef XmtCReplaceOnError
#define XmtCReplaceOnError ((char*)&XmtInputFieldStrings[367])
#endif
#ifndef XmtCTargetSymbolName
#define XmtCTargetSymbolName ((char*)&XmtInputFieldStrings[382])
#endif
#ifndef XmtRXmtInputFieldActions
#define XmtRXmtInputFieldActions ((char*)&XmtInputFieldStrings[444])
#endif

_XFUNCPROTOBEGIN
#if NeedFunctionPrototypes
extern Widget XmtCreateInputField(Widget, StringConst, ArgList, Cardinal);
extern void XmtRegisterInputField(void);
extern String XmtInputFieldGetString(Widget);
extern void XmtInputFieldSetString(Widget, StringConst);
#else
extern Widget XmtCreateInputField();
extern void XmtRegisterInputField();
extern String XmtInputFieldGetString();
extern void XmtInputFieldSetString();
#endif
_XFUNCPROTOEND    

#endif /* _XmtInputField_h */
